@@ -31,7 +31,6 @@
  */
 
 
-
 #pragma once
 
 
@@ -50,31 +49,25 @@
 
 namespace msXpSlibmass
 {
-	class DataPoint;
+class DataPoint;
 
-	class DataPointJsPrototype
-		:
-			public QObject,
-			public QScriptable
-	{
-		Q_OBJECT
+class DataPointJsPrototype : public QObject, public QScriptable
+{
+  Q_OBJECT
 
-		private:
+  private:
+  DataPoint *thisDataPoint() const;
 
-			DataPoint *thisDataPoint() const;
+  public:
+  DataPointJsPrototype(QObject *parent = 0);
+  ~DataPointJsPrototype();
 
-		public:
+  public slots:
 
-			DataPointJsPrototype(QObject *parent = 0);
-			~DataPointJsPrototype();
+  bool initialize();
+  bool isValid() const;
 
-			public slots:
-
-				bool initialize();
-			bool isValid() const;
-
-			QScriptValue valueOf() const;
-	};
+  QScriptValue valueOf() const;
+};
 
 } // namespace msXpSlibmass
-
