@@ -105,7 +105,7 @@ MassSpectrum::MassSpectrum(const Trace &other) : Trace(other)
 
 //! Construct a MassSpectrum with \p title
 /*!
-*/
+ */
 MassSpectrum::MassSpectrum(const QString &title) : Trace{title}
 {
 }
@@ -480,17 +480,18 @@ MassSpectrum::determineMzShift(const MassSpectrum &other)
 //! Computes the mz shift between \p otherMzValue and \c this MassSpectrum
 /*!
 
-		The shift is computed by making the difference between the keys \p
-		otherMzValue and \this MassSpectrum instance' first DataPoint instance.
+    The shift is computed by making the difference between the keys \p
+    otherMzValue and \this MassSpectrum instance' first DataPoint instance.
 
-		As a side effect, \c m_mzShift is set to this difference value.
+    As a side effect, \c m_mzShift is set to this difference value.
 
-		\param otherMzValue mz value to use for the m/z shift calculation against \c
-		this MassSpectrum's first DataPoint instance.
+    \param otherMzValue mz value to use for the m/z shift calculation against \c
+    this MassSpectrum's first DataPoint instance.
 
-		\return a double containing the m/z shift.
+    \return a double containing the m/z shift.
 
-*/ double
+*/
+double
 MassSpectrum::determineMzShift(double otherMzValue)
 {
   if(!size())
@@ -592,7 +593,7 @@ MassSpectrum::tic(const QList<MassSpectrum *> &massSpectra)
 int
 MassSpectrum::combine(const MassSpectrum &other, double mzStart, double mzEnd)
 {
-  //qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
+  // qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
 
   // We receive a spectrum that we need to combine into this mass spectrum.
   // However, we need to check each individual DataPoint of the MassSpectrum
@@ -694,7 +695,7 @@ MassSpectrum::subtract(const MassSpectrum &other, double mzStart, double mzEnd)
 int
 MassSpectrum::combine(const Trace &trace, double mzStart, double mzEnd)
 {
-  //qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
+  // qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
 
   MassSpectrum mass_spectrum(trace);
 
@@ -705,7 +706,7 @@ MassSpectrum::combine(const Trace &trace, double mzStart, double mzEnd)
 int
 MassSpectrum::subtract(const Trace &trace, double mzStart, double mzEnd)
 {
-  //qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
+  // qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
 
   MassSpectrum mass_spectrum(trace);
 
@@ -919,8 +920,8 @@ MassSpectrum::combine(const QList<MassSpectrum *> &massSpectra,
             }
         }
 
-// At this point we have setup all the slices to combine them in their
-// own combined mass spectrum.
+        // At this point we have setup all the slices to combine them in their
+        // own combined mass spectrum.
 
 #pragma omp parallel for shared(count)
       // This code was tested to provide identical results as when run in
@@ -975,8 +976,8 @@ MassSpectrum::combine(const QList<MassSpectrum *> &massSpectra,
 
   if(m_removeZeroValDataPoints)
     {
-      //qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-               //<< "Now removing all 0-m/z data points.";
+      // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+      //<< "Now removing all 0-m/z data points.";
 
       removeZeroValDataPoints();
     }
@@ -1215,8 +1216,8 @@ MassSpectrum::subtract(const QList<MassSpectrum *> &massSpectra,
             }
         }
 
-// At this point we have setup all the slices to subtract them in their
-// own subtractd mass spectrum.
+        // At this point we have setup all the slices to subtract them in their
+        // own subtractd mass spectrum.
 
 #pragma omp parallel for shared(count)
       // This code was tested to provide identical results as when run in
@@ -1272,8 +1273,8 @@ MassSpectrum::subtract(const QList<MassSpectrum *> &massSpectra,
 
   if(m_removeZeroValDataPoints)
     {
-      //qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-               //<< "Now removing all 0-m/z data points.";
+      // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+      //<< "Now removing all 0-m/z data points.";
 
       removeZeroValDataPoints();
     }
@@ -1963,7 +1964,7 @@ MassSpectrum::setupBinnability(const MassSpectrum &massSpectrum)
 int
 MassSpectrum::populateSpectrumWithArbitraryBins()
 {
-  //qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
+  // qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
 
   if(size() != 0)
     qFatal(
@@ -1995,10 +1996,10 @@ MassSpectrum::populateSpectrumWithArbitraryBins()
       __LINE__,
       __FUNCTION__);
 
-  //qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-           //<< QString::asprintf("bin size: %.6f and decimal places: %d\n",
-                                //m_binSize,
-                                //m_decimalPlaces);
+  // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+  //<< QString::asprintf("bin size: %.6f and decimal places: %d\n",
+  // m_binSize,
+  // m_decimalPlaces);
 
   // Now that we have defined the value of m_decimalPlaces, let's use that
   // value.
@@ -2008,10 +2009,10 @@ MassSpectrum::populateSpectrumWithArbitraryBins()
   double lastMz = ceil((m_maxMz * pow(10, m_decimalPlaces)) - 0.49) /
                   pow(10, m_decimalPlaces);
 
-  //qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-           //<< QString::asprintf("Very first data point: %.6f\n", firstMz)
-           //<< QString::asprintf("Very last data point to reach: %.6f\n",
-                                //lastMz);
+  // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+  //<< QString::asprintf("Very first data point: %.6f\n", firstMz)
+  //<< QString::asprintf("Very last data point to reach: %.6f\n",
+  // lastMz);
 
   // That is the very first data point in *this spectrum.
 
@@ -2026,7 +2027,7 @@ MassSpectrum::populateSpectrumWithArbitraryBins()
   // lastMz.
 
   // debugCount value used below for debugging purposes.
-  //int debugCount = 0;
+  // int debugCount = 0;
 
   while(previousMzBin < lastMz)
     {
@@ -2052,18 +2053,18 @@ MassSpectrum::populateSpectrumWithArbitraryBins()
       currentMz = ceil((currentMz * pow(10, m_decimalPlaces)) - 0.49) /
                   pow(10, m_decimalPlaces);
 
-			//if(debugCount == 0)
-				//{
-					//double mzDiff = currentMz - previousMzBin;
-					//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-									 //<< QString(
-												//"previousMzBin: %1 - currentMz: %2 - mzDiff: %3 - "
-												//"m_decimalPlaces: %4")
-												//.arg(previousMzBin, 0, 'f', 10)
-												//.arg(currentMz, 0, 'f', 10)
-												//.arg(mzDiff, 0, 'f', 10)
-												//.arg(m_decimalPlaces);
-				//}
+      // if(debugCount == 0)
+      //{
+      // double mzDiff = currentMz - previousMzBin;
+      // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+      //<< QString(
+      //"previousMzBin: %1 - currentMz: %2 - mzDiff: %3 - "
+      //"m_decimalPlaces: %4")
+      //.arg(previousMzBin, 0, 'f', 10)
+      //.arg(currentMz, 0, 'f', 10)
+      //.arg(mzDiff, 0, 'f', 10)
+      //.arg(m_decimalPlaces);
+      //}
 
       double roundedMz = ceil((currentMz * pow(10, m_decimalPlaces)) - 0.49) /
                          pow(10, m_decimalPlaces);
@@ -2087,16 +2088,16 @@ MassSpectrum::populateSpectrumWithArbitraryBins()
                  roundedMz);
         }
 
-      //if(debugCount == 0)
-        //qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-                 //<< QString("After decimals accounting: roundedMz: %1")
-                      //.arg(roundedMz, 0, 'f', 10);
+      // if(debugCount == 0)
+      // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+      //<< QString("After decimals accounting: roundedMz: %1")
+      //.arg(roundedMz, 0, 'f', 10);
 
-      //if(debugCount == 0)
-        //qDebug() << __FILE__ << __LINE__
-                 //<< QString("Append bin mz: %1 from computation %2\n")
-                      //.arg(roundedMz, 0, 'f', 10)
-                      //.arg(previousMzBin, 0, 'f', 10);
+      // if(debugCount == 0)
+      // qDebug() << __FILE__ << __LINE__
+      //<< QString("Append bin mz: %1 from computation %2\n")
+      //.arg(roundedMz, 0, 'f', 10)
+      //.arg(previousMzBin, 0, 'f', 10);
 
       append(new DataPoint(roundedMz, 0));
 
@@ -2104,8 +2105,8 @@ MassSpectrum::populateSpectrumWithArbitraryBins()
       previousMzBin = roundedMz;
 
       // Do the debugging only once each 1000 mz values.
-      //if(++debugCount == 100)
-        //debugCount = 0;
+      // if(++debugCount == 100)
+      // debugCount = 0;
     }
 
 #if 0
@@ -2404,4 +2405,3 @@ MassSpectrum::cancelOperation()
 }
 
 } // namespace msXpSlibmass
-
