@@ -31,7 +31,6 @@
  */
 
 
-
 #include <QtScript/QScriptEngine>
 
 #include <libmass/MassSpectrumJsPropertyIterator.hpp>
@@ -42,79 +41,81 @@ namespace msXpSlibmass
 {
 
 
-	MassSpectrumJsPropertyIterator::MassSpectrumJsPropertyIterator(const QScriptValue &object)
-		: QScriptClassPropertyIterator(object)
-	{
-		toFront();
-	}
+MassSpectrumJsPropertyIterator::MassSpectrumJsPropertyIterator(
+  const QScriptValue &object)
+  : QScriptClassPropertyIterator(object)
+{
+  toFront();
+}
 
 
-	MassSpectrumJsPropertyIterator::~MassSpectrumJsPropertyIterator()
-	{
-	}
+MassSpectrumJsPropertyIterator::~MassSpectrumJsPropertyIterator()
+{
+}
 
 
-	bool
-		MassSpectrumJsPropertyIterator::hasNext() const
-		{
-			MassSpectrum *massSpectrum = qscriptvalue_cast<MassSpectrum*>(object().data());
-			return m_index < massSpectrum->size();
-		}
+bool
+MassSpectrumJsPropertyIterator::hasNext() const
+{
+  MassSpectrum *massSpectrum =
+    qscriptvalue_cast<MassSpectrum *>(object().data());
+  return m_index < massSpectrum->size();
+}
 
 
-	void
-		MassSpectrumJsPropertyIterator::next()
-		{
-			m_last = m_index;
-			++m_index;
-		}
+void
+MassSpectrumJsPropertyIterator::next()
+{
+  m_last = m_index;
+  ++m_index;
+}
 
 
-	bool
-		MassSpectrumJsPropertyIterator::hasPrevious() const
-		{
-			return (m_index > 0);
-		}
+bool
+MassSpectrumJsPropertyIterator::hasPrevious() const
+{
+  return (m_index > 0);
+}
 
 
-	void
-		MassSpectrumJsPropertyIterator::previous()
-		{
-			--m_index;
-			m_last = m_index;
-		}
+void
+MassSpectrumJsPropertyIterator::previous()
+{
+  --m_index;
+  m_last = m_index;
+}
 
 
-	void
-		MassSpectrumJsPropertyIterator::toFront()
-		{
-			m_index = 0;
-			m_last = -1;
-		}
+void
+MassSpectrumJsPropertyIterator::toFront()
+{
+  m_index = 0;
+  m_last  = -1;
+}
 
 
-	void
-		MassSpectrumJsPropertyIterator::toBack()
-		{
-			MassSpectrum *massSpectrum = qscriptvalue_cast<MassSpectrum*>(object().data());
-			m_index = massSpectrum->size();
-			m_last = -1;
-		}
+void
+MassSpectrumJsPropertyIterator::toBack()
+{
+  MassSpectrum *massSpectrum =
+    qscriptvalue_cast<MassSpectrum *>(object().data());
+  m_index = massSpectrum->size();
+  m_last  = -1;
+}
 
 
-	QScriptString
-		MassSpectrumJsPropertyIterator::name() const
-		{
-			return object().engine()->toStringHandle(QString::number(m_last));
-		}
+QScriptString
+MassSpectrumJsPropertyIterator::name() const
+{
+  return object().engine()->toStringHandle(QString::number(m_last));
+}
 
 
-	uint
-		MassSpectrumJsPropertyIterator::id() const
-		{
-			return m_last;
-		}
+uint
+MassSpectrumJsPropertyIterator::id() const
+{
+  return m_last;
+}
 
 
 } // namespace msXpSlibmass
-
