@@ -31,7 +31,6 @@
  */
 
 
-
 #include <QScriptClassPropertyIterator>
 
 
@@ -39,31 +38,28 @@ namespace msXpSlibmass
 {
 
 
-class MassSpectrumJsPropertyIterator
-:
-	public QScriptClassPropertyIterator
+class MassSpectrumJsPropertyIterator : public QScriptClassPropertyIterator
 {
-	private:
-		int m_index;
-		int m_last;
+  private:
+  int m_index;
+  int m_last;
 
-	public:
-		MassSpectrumJsPropertyIterator(const QScriptValue &object);
-		~MassSpectrumJsPropertyIterator();
+  public:
+  MassSpectrumJsPropertyIterator(const QScriptValue &object);
+  ~MassSpectrumJsPropertyIterator();
 
-		bool hasNext() const;
-		void next();
+  bool hasNext() const;
+  void next();
 
-		bool hasPrevious() const;
-		void previous();
+  bool hasPrevious() const;
+  void previous();
 
-		void toFront();
-		void toBack();
+  void toFront();
+  void toBack();
 
-		QScriptString name() const;
-		uint id() const;
+  QScriptString name() const;
+  uint id() const;
 };
 
 
 } // namespace msXpSlibmass
-
