@@ -31,7 +31,6 @@
  */
 
 
-
 #pragma once
 
 
@@ -50,43 +49,37 @@
 
 namespace msXpSlibmass
 {
-	class MassSpectrum;
+class MassSpectrum;
 
-	class MassSpectrumJsPrototype
-		:
-			public QObject,
-			public QScriptable
-	{
-		Q_OBJECT
+class MassSpectrumJsPrototype : public QObject, public QScriptable
+{
+  Q_OBJECT
 
-		private:
+  private:
+  MassSpectrum *thisMassSpectrum() const;
 
-			MassSpectrum *thisMassSpectrum() const;
+  public:
+  MassSpectrumJsPrototype(QObject *parent = Q_NULLPTR);
+  ~MassSpectrumJsPrototype();
 
-		public:
+  public slots:
 
-			MassSpectrumJsPrototype(QObject *parent = Q_NULLPTR);
-			~MassSpectrumJsPrototype();
+  int initialize();
+  int initializeOneArgument();
+  int initializeTwoArguments();
+  int initializeFourArguments();
 
-			public slots:
+  QList<double> mzArray() const;
+  QList<double> iArray() const;
 
-				int initialize();
-			int initializeOneArgument();
-			int initializeTwoArguments();
-			int initializeFourArguments();
+  QString asText() const;
 
-			QList<double> mzArray() const;
-			QList<double> iArray() const;
+  double tic() const;
 
-			QString asText() const;
+  int combine();
+  int subtract();
 
-			double tic() const;
-
-			int combine();
-			int subtract();
-
-			QScriptValue valueOf() const;
-	};
+  QScriptValue valueOf() const;
+};
 
 } // namespace msXpSlibmass
-
