@@ -65,7 +65,7 @@ int tracePtrMetaTypeId =
 
 //! Construct a totally empty Trace
 /*!
-*/
+ */
 Trace::Trace()
 {
   // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
@@ -76,7 +76,7 @@ Trace::Trace()
 
 //! Construct a Trace with \p title
 /*!
-*/
+ */
 Trace::Trace(const QString &title)
 {
   m_title = title;
@@ -188,8 +188,8 @@ Trace::reset()
 void
 Trace::deleteDataPoints()
 {
-// qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-//<< "this trace:" << this << "with size:" << size();
+  // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+  //<< "this trace:" << this << "with size:" << size();
 
 #pragma omp parallel for
   for(int iter = 0; iter < size(); ++iter)
@@ -657,11 +657,11 @@ Trace::valSum() const
 
 #pragma omp parallel
   {
-// int maxNumbThreads = omp_get_max_threads();
-// omp_set_num_threads(10);
-// int numbThreads = omp_get_num_threads();
-// qDebug() << __FILE__ << __LINE__
-// << "Number of threads: " << numbThreads << "over" << maxNumbThreads;
+    // int maxNumbThreads = omp_get_max_threads();
+    // omp_set_num_threads(10);
+    // int numbThreads = omp_get_num_threads();
+    // qDebug() << __FILE__ << __LINE__
+    // << "Number of threads: " << numbThreads << "over" << maxNumbThreads;
 
 #pragma omp for reduction(+ : valSum)
     // 20160921 - This code was tested to provide identical results to the
@@ -705,11 +705,11 @@ Trace::valSum(double keyStart, double keyEnd) const
 
 #pragma omp parallel
   {
-// int maxNumbThreads = omp_get_max_threads();
-// omp_set_num_threads(10);
-// int numbThreads = omp_get_num_threads();
-// qDebug() << __FILE__ << __LINE__
-// << "Number of threads: " << numbThreads << "over" << maxNumbThreads;
+    // int maxNumbThreads = omp_get_max_threads();
+    // omp_set_num_threads(10);
+    // int numbThreads = omp_get_num_threads();
+    // qDebug() << __FILE__ << __LINE__
+    // << "Number of threads: " << numbThreads << "over" << maxNumbThreads;
 
 #pragma omp for reduction(+ : valSum)
     for(int iter = 0; iter < size(); ++iter)
@@ -1152,10 +1152,10 @@ Trace::combineMonoT(const QList<Trace *> &traceList)
 
 #endif
     }
-// qDebug() << __FILE__ << __LINE__
-// << "Effectively combined " << count
-// << "Trace instances in this Trace for a total of "
-// << size() << "data points";
+    // qDebug() << __FILE__ << __LINE__
+    // << "Effectively combined " << count
+    // << "Trace instances in this Trace for a total of "
+    // << size() << "data points";
 
 #if 0
 			QString fileName = "/tmp/unranged-combined-trace-after-finishing-combinations.txt";
@@ -1275,13 +1275,13 @@ Trace::combine(const QList<Trace *> &traceList)
             }
         }
 
-// At this point we have setup all the slices to combine them in their
-// own combined trace.
+        // At this point we have setup all the slices to combine them in their
+        // own combined trace.
 
 #pragma omp parallel for shared(count)
       for(int iter = 0; iter < maxThreads; ++iter)
         {
-          Trace *p_combinedTrace = combinedTraceList.at(iter);
+          Trace *p_combinedTrace        = combinedTraceList.at(iter);
           QPair<int, int> *p_indexRange = indexRangeList.at(iter);
 
           int combineCount = p_combinedTrace->combineSlice(
@@ -1528,13 +1528,13 @@ Trace::subtract(const QList<Trace *> &traceList)
             }
         }
 
-// At this point we have setup all the slices to subtract them in their
-// own subtractd trace.
+        // At this point we have setup all the slices to subtract them in their
+        // own subtractd trace.
 
 #pragma omp parallel for shared(count)
       for(int iter = 0; iter < maxThreads; ++iter)
         {
-          Trace *p_subtractedTrace = subtractedTraceList.at(iter);
+          Trace *p_subtractedTrace      = subtractedTraceList.at(iter);
           QPair<int, int> *p_indexRange = indexRangeList.at(iter);
 
           int subtractCount = p_subtractedTrace->subtractSlice(
@@ -1686,10 +1686,10 @@ Trace::combine(const QList<Trace *> &traces, double keyStart, double keyEnd)
       ++count;
     }
 
-// qDebug() << __FILE__ << __LINE__
-// << "Effectively combined " << count
-// << "in this Trace for a total of "
-// << size() << "data points";
+    // qDebug() << __FILE__ << __LINE__
+    // << "Effectively combined " << count
+    // << "in this Trace for a total of "
+    // << size() << "data points";
 
 #if 0
 			QString fileName = "/tmp/mzranged-combined-trace-after-finishing-combinations.txt";
@@ -2037,18 +2037,19 @@ Trace::toLists(QList<double> *keyList, QList<double> *valList) const
 //! Fills in vectors of double values containing the data of \c this Trace.
 /*!
 
-		The program crashes if any of the pointers is Q_NULLPTR.
+    The program crashes if any of the pointers is Q_NULLPTR.
 
-		\param keyVector pointer to a double vector where to store all the keys of
-		the DataPoint instances of \c this Trace
+    \param keyVector pointer to a double vector where to store all the keys of
+    the DataPoint instances of \c this Trace
 
-		\param valVector pointer to a double vector where to store all the intensity
-		values of the DataPoint instances of \c this Trace
+    \param valVector pointer to a double vector where to store all the intensity
+    values of the DataPoint instances of \c this Trace
 
-		The vectors are filled in the same order as the DataPoint instances are listed
-		in \c this Trace, thus reflecting perfectly the mass spectral data.
+    The vectors are filled in the same order as the DataPoint instances are
+   listed in \c this Trace, thus reflecting perfectly the mass spectral data.
 
-*/ void
+*/
+void
 Trace::toVectors(QVector<double> *keyVector, QVector<double> *valVector) const
 {
   if(!keyVector || !valVector)
@@ -2067,15 +2068,16 @@ Trace::toVectors(QVector<double> *keyVector, QVector<double> *valVector) const
 //! Fills in a map with the data of \c this Trace.
 /*!
 
-		The program crashes if the pointer is Q_NULLPTR.
+    The program crashes if the pointer is Q_NULLPTR.
 
-		\param map pointer to a <double,double> map in which to store all the
-		(key,value) pairs of this \c Trace.
+    \param map pointer to a <double,double> map in which to store all the
+    (key,value) pairs of this \c Trace.
 
-		The map is ordered by definition in ascending order with respect to the key
-		(the key), irrespective of the value (the value).
+    The map is ordered by definition in ascending order with respect to the key
+    (the key), irrespective of the value (the value).
 
-*/ void
+*/
+void
 Trace::toMap(QMap<double, double> *map) const
 {
   if(!map)
