@@ -61,7 +61,7 @@ Application::Application(int &argc, char **argv, const QString &moduleName)
   QCoreApplication::setOrganizationDomain("msxpertsuite.org");
   QCoreApplication::setApplicationName(m_moduleName);
 
-  QString pixmapFileName = ":/images/msxpertsuite-icon-32.png";
+  QString pixmapFileName = ":/images/icons/32x32/massxpert.png";
   QPixmap iconPixmap(pixmapFileName);
   QIcon icon(iconPixmap);
 
