@@ -31,8 +31,6 @@
  */
 
 
-
-
 #ifndef CHEM_PAD_BUTTON_HPP
 #define CHEM_PAD_BUTTON_HPP
 
@@ -43,25 +41,29 @@
 
 namespace msXpSmassXpert
 {
-  class CalculatorWnd;
+class CalculatorWnd;
 
-  class ChemPadButton : public QPushButton
-  {
-    Q_OBJECT
+class ChemPadButton : public QPushButton
+{
+  Q_OBJECT
 
-    private:
-    QString        m_formula;
-    CalculatorWnd *mp_calculatorWnd;
+  private:
+  QString m_formula;
+  CalculatorWnd *mp_calculatorWnd;
 
-    public:
-    ChemPadButton(const QString &, const QString &, QWidget *, QWidget * = 0,
-                  const QColor & = QColor(), const QColor & = QColor());
+  public:
+  ChemPadButton(const QString &,
+                const QString &,
+                QWidget *,
+                QWidget *      = 0,
+                const QColor & = QColor(),
+                const QColor & = QColor());
 
-    ~ChemPadButton();
+  ~ChemPadButton();
 
-    public slots:
-    void clicked();
-  };
+  public slots:
+  void clicked();
+};
 
 } // namespace msXpSmassXpert
 
