@@ -136,10 +136,6 @@ MzLabWnd::initialize()
 {
   m_ui.setupUi(this);
 
-  QPixmap pixmap(":/images/msxpertsuite-icon-32.png");
-  QIcon icon(pixmap);
-  setWindowIcon(icon);
-
   setAttribute(Qt::WA_DeleteOnClose);
   statusBar()->setSizeGripEnabled(true);
 
