@@ -673,10 +673,6 @@ SequenceEditorWnd::initialize()
   mpa_resultsString = new QString();
   //////////////////////////////////// The results-exporting menus.
 
-  QPixmap pixmap(":/images/msxpertsuite-icon-32.png");
-  QIcon icon(pixmap);
-  setWindowIcon(icon);
-
   createActions();
   createMenus();
 
