@@ -31,8 +31,6 @@
  */
 
 
-
-
 #ifndef CHEMICAL_GROUP_RULE_HPP
 #define CHEMICAL_GROUP_RULE_HPP
 
@@ -46,40 +44,41 @@
 namespace msXpSmassXpert
 {
 
-  enum
+enum
+{
+  CHEMGROUP_RULE_LOST      = 0,
+  CHEMGROUP_RULE_PRESERVED = 1,
+};
+
+
+class ChemicalGroupRule
+{
+  private:
+  QString m_entity;
+
+  QString m_name;
+
+  int m_outcome;
+
+  public:
+  ChemicalGroupRule(QString = QString(),
+                    QString = QString(),
+                    int     = CHEMGROUP_RULE_LOST);
+  ~ChemicalGroupRule()
   {
-    CHEMGROUP_RULE_LOST      = 0,
-    CHEMGROUP_RULE_PRESERVED = 1,
-  };
+  }
 
+  void setEntity(QString);
+  QString entity();
 
-  class ChemicalGroupRule
-  {
-    private:
-    QString m_entity;
+  void setName(QString);
+  QString name();
 
-    QString m_name;
+  void setOutcome(int);
+  int outcome();
 
-    int m_outcome;
-
-    public:
-    ChemicalGroupRule(QString = QString(), QString = QString(),
-                      int = CHEMGROUP_RULE_LOST);
-    ~ChemicalGroupRule()
-    {
-    }
-
-    void    setEntity(QString);
-    QString entity();
-
-    void    setName(QString);
-    QString name();
-
-    void setOutcome(int);
-    int  outcome();
-
-    bool renderXmlElement(const QDomElement &element);
-  };
+  bool renderXmlElement(const QDomElement &element);
+};
 
 } // namespace msXpSmassXpert
 
