@@ -244,6 +244,10 @@ AbstractMultiPlotWnd::setupWindow()
   mp_toolbar = addToolBar("Settings");
   mp_toolbar->setObjectName(QStringLiteral("mp_toolbar"));
 
+  // Make sure a right mouse button click does not elicit the context menu that
+  // when clicked made the toolbar disappear totally.
+  mp_toolbar->setContextMenuPolicy(Qt::PreventContextMenu);
+
   const QIcon xRangeIcon = QIcon(":/images/lock-x-range.png");
   mp_lockXRangeAct       = new QAction(xRangeIcon, tr("Lock X range"), this);
   mp_lockXRangeAct->setCheckable(true);
