@@ -572,14 +572,14 @@ DriftSpecPlotWidget::jsIntegrateToRt(double lower, double upper)
 
   AbstractMultiPlotWnd *targetWnd = mainWindow->mp_ticChromWnd;
 
-	qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+  qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 
-  static_cast<TicChromWnd *>(targetWnd)
-    ->jsNewTicChromatogram(this,
-                         mp_massSpecDataSet,
-                         "Calculating drift spectrum.",
-                         localHistory,
-                         m_plottingColor);
+  static_cast<TicChromWnd *>(targetWnd)->jsNewTicChromatogram(
+    this,
+    mp_massSpecDataSet,
+    "Calculating drift spectrum.",
+    localHistory,
+    m_plottingColor);
 }
 
 
