@@ -275,7 +275,7 @@ DriftSpecWnd::addPlotWidget(const QVector<double> &keyVector,
   mp_multiGraphPlotWidget->rescaleAxes(true /*only enlarge*/);
   mp_multiGraphPlotWidget->replot();
 
-	widget->setMultiGraph(newGraph);
+  widget->setMultiGraph(newGraph);
 
   // Maintain a hash connection between any given plot widget and the
   // corresponding graph in the multigraph widget.
@@ -493,7 +493,7 @@ DriftSpecWnd::newDriftSpectrumDone(MassDataIntegrator *integrator,
 //! Integrate data to a drift spectrum starting from TIC chromatogram.
 /*!
 
-	\param caller pointer to the caller widget.
+  \param caller pointer to the caller widget.
 
   \param massSpecDataSet pointer to the MassSpecDataSet where the mass data
   are stored.
@@ -507,12 +507,12 @@ DriftSpecWnd::newDriftSpectrumDone(MassDataIntegrator *integrator,
 */
 void
 DriftSpecWnd::jsNewDriftSpectrum(AbstractPlotWidget *caller,
-		const MassSpecDataSet *massSpecDataSet,
+                                 const MassSpecDataSet *massSpecDataSet,
                                  const QString &msg,
                                  History history,
                                  QColor color)
 {
-	qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+  qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
 
   if(massSpecDataSet == Q_NULLPTR)
     qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
@@ -634,11 +634,11 @@ DriftSpecWnd::jsNewDriftSpectrum(AbstractPlotWidget *caller,
           &DriftSpecWnd::ticIntensity);
 
 
-  //AbstractPlotWidget *senderPlotWidget =
-    //static_cast<AbstractPlotWidget *>(QObject::sender());
+  // AbstractPlotWidget *senderPlotWidget =
+  // static_cast<AbstractPlotWidget *>(QObject::sender());
 
-  //if(senderPlotWidget == Q_NULLPTR)
-    //qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+  // if(senderPlotWidget == Q_NULLPTR)
+  // qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
   mainWindow->m_dataPlotWidgetRelationer.newRelation(
     massSpecDataSet,
@@ -916,4 +916,4 @@ DriftSpecWnd::focusNextPrevChild(bool next)
 }
 
 
-} // namespace msxpertsuite
+} // namespace msXpSmineXpert
