@@ -227,6 +227,45 @@ IsoSpecDlg::setupDialog()
 }
 
 
+QString
+IsoSpecDlg::formatLibIsoSpecAtomAsMassXpertXmlElement(const msXpSlibmass::Atom &atom)
+{
+  // This function is merely utilitary when we want to parse the IsoSpec
+  // library's data into a massXpert xml format.
+
+	// We do not indent the text, any editor will do.
+	
+  QString text = "<atom>\n";
+
+  QString capitalized_name = atom.name().replace(0, 1, atom.name().at(0).toUpper());
+
+  text += QString("<name>%2</name>\n").arg(capitalized_name);
+
+  text += QString("<symbol>%2</symbol>\n").arg(atom.symbol());
+
+  // At this point we have the different isotope(s) of the atom. We
+  // delegate that to the appropriate function of the isotope class.
+
+  for(int iter = 0; iter < atom.isotopeList().size(); ++iter)
+    {
+			msXpSlibmass::Isotope isotope(*atom.isotopeList().at(iter));
+
+			text += "<isotope>\n";
+
+      text += QString("<mass>%1</mass>\n").arg(QString::number(isotope.mass(), 'f', 10));
+			// The libIsoSpec++ library stores abundance data in the form of
+			// probabilities and not percentages. We thus need to * 100 the abundance.
+      text += QString("<abundance>%1</abundance>\n").arg(QString::number(100 * isotope.abundance(), 'f', 60));
+
+      text += QString("</isotope>\n");
+    }
+
+  text += "</atom>\n";
+
+  return text;
+}
+
+
 bool
 IsoSpecDlg::initializeIsoSpecStandardStaticEntityList()
 {
@@ -249,6 +288,15 @@ IsoSpecDlg::initializeIsoSpecStandardStaticEntityList()
   // extern const double
   // elem_table_log_probability[ISOSPEC_NUMBER_OF_ISOTOPIC_ENTRIES];
 
+
+  // This was used to export in the format of massXpert's polChemDef the
+  // atoms parsed from the libIsoSpec++ lib. See below, same commented text.
+
+	 QFile file("/tmp/atom_data_as_mxp_pol_chem_def_data");
+	 file.open(QFile::WriteOnly | QFile::Truncate);
+	 QTextStream textStream(&file);
+
+
   // Big sanity check, all the arrays must be the same length!
   std::size_t arrayLength = checkConsistencyIsoSpecTables();
   if(arrayLength < 1)
@@ -326,6 +374,11 @@ IsoSpecDlg::initializeIsoSpecStandardStaticEntityList()
               // This vector is the one that will actually free the Atom*
               // instances when closing the dialog.
               m_isoSpecStandardStaticAtomVector.push_back(atom);
+
+              // This was used to export in the format of massXpert's polChemDef
+              // the atoms parsed from the libIsoSpec++ lib.
+
+							 textStream << formatLibIsoSpecAtomAsMassXpertXmlElement(*atom);
             }
 
           // Now start with the new atom.
@@ -377,8 +430,18 @@ IsoSpecDlg::initializeIsoSpecStandardStaticEntityList()
 
       m_isoSpecStandardStaticAtomList.append(atom);
       m_isoSpecStandardStaticAtomVector.push_back(atom);
+
+
+      // This was used to export in the format of massXpert's polChemDef the
+      // atoms parsed from the libIsoSpec++ lib.
+
+			textStream << formatLibIsoSpecAtomAsMassXpertXmlElement(*atom);
     }
 
+  // This was used to export in the format of massXpert's polChemDef the atoms
+  // parsed from the libIsoSpec++ lib.
+  // file.close();
+
   // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
   ////<< "The list has" << m_isoSpecEntityList.size() << "items"
   ////<< "The atom list has" << m_isoSpecAtomList.size() << "atoms";
@@ -584,7 +647,7 @@ IsoSpecDlg::saveIsoSpecStandardUserTables()
 bool
 IsoSpecDlg::loadIsoSpecStandardUserTables()
 {
-  //qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
+  // qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
 
   // The format of the file from which data is to be loaded is mimicking the
   // tables that are defined as a number of C arrays in the libIsoSpec++ header
@@ -644,8 +707,8 @@ IsoSpecDlg::loadIsoSpecStandardUserTables()
     {
       QString line = in.readLine();
 
-      //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-               //<< "line:" << line;
+      // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+      //<< "line:" << line;
 
       // Ignore empty or comment lines
       if(line.length() < 1)
@@ -822,8 +885,8 @@ IsoSpecDlg::loadIsoSpecStandardUserTables()
   // End of
   // while(!in.atEnd())
 
-  //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-           //<< "Finished creating all the IsoSpecEntity instances.";
+  // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+  //<< "Finished creating all the IsoSpecEntity instances.";
 
   file.close();
 
@@ -832,13 +895,13 @@ IsoSpecDlg::loadIsoSpecStandardUserTables()
   // There might be old entities in the user table view/model, so first remove
   // everything and then add the new ones.
 
-  //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-           //<< "Now removing the old entities";
+  // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+  //<< "Now removing the old entities";
 
   mpa_isoSpecStandardUserTableViewModel->removeIsoSpecEntities(0, -1);
 
-  //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-           //<< "Now adding the new entities";
+  // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+  //<< "Now adding the new entities";
 
   mpa_isoSpecStandardUserTableViewModel->addIsoSpecEntities(isoSpecEntityList);
 
@@ -1563,7 +1626,7 @@ IsoSpecDlg::checkConsistencyIsoSpecTables()
 bool
 IsoSpecDlg::runIsoSpecStandardStaticConfig()
 {
-  //qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
+  // qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
 
   // This is the configuration of elements/isotopes that is loaded from the
   // IsoSpec library headers, that is, the configuration is static.
@@ -1626,7 +1689,7 @@ IsoSpecDlg::runIsoSpecStandardStaticConfig()
 bool
 IsoSpecDlg::runIsoSpecStandardUserConfig()
 {
-  //qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
+  // qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
 
   // When running this function, the user must have a correct atom/isotope
   // configuration in the tableview and a formula that matches the available
@@ -1666,7 +1729,7 @@ IsoSpecDlg::runIsoSpecStandardUserConfig()
   if(!errors.isEmpty())
     {
       message(errors, 5000);
-			return false;
+      return false;
     }
   else
     {
@@ -2019,8 +2082,8 @@ IsoSpecDlg::runIsoSpecManualConfig()
 
   for(std::size_t iter = 0; iter < elementNumber; ++iter)
     {
-      delete isotope_masses[iter];
-      delete isotope_probs[iter];
+      delete[] isotope_masses[iter];
+      delete[] isotope_probs[iter];
     }
 
   return true;
