@@ -153,7 +153,7 @@ MainWindow::setupWindow()
   // Create the actions and menus of the main window.
   createMenusAndActions();
 
-  QPixmap pixmap(":/images/msxpertsuite-icon-32.png");
+  QPixmap pixmap(":/images/icons/32x32/minexpert.png");
   QIcon icon(pixmap);
   setWindowIcon(icon);
 
