@@ -95,9 +95,17 @@ PeakShaperDlg::~PeakShaperDlg()
 void
 PeakShaperDlg::writeSettings()
 {
+  // qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
+
   QSettings settings;
   settings.beginGroup("PeakShaperDlg");
   settings.setValue("geometry", saveGeometry());
+  settings.setValue("pointCount", m_ui.pointCountSpinBox->value());
+  settings.setValue("resolution", m_ui.resolutionSpinBox->value());
+  settings.setValue("charge", m_ui.ionChargeSpinBox->value());
+  settings.setValue("fwhm", m_ui.fwhmDoubleSpinBox->value());
+  settings.setValue("binSize", m_ui.binSizeDoubleSpinBox->value());
+  settings.setValue("splitter", m_ui.splitter->saveState());
   settings.endGroup();
 }
 
@@ -106,9 +114,17 @@ PeakShaperDlg::writeSettings()
 void
 PeakShaperDlg::readSettings()
 {
+  // qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
+
   QSettings settings;
   settings.beginGroup("PeakShaperDlg");
   restoreGeometry(settings.value("geometry").toByteArray());
+  m_ui.pointCountSpinBox->setValue(settings.value("pointCount", 150).toInt());
+  m_ui.resolutionSpinBox->setValue(settings.value("resolution", 45000).toInt());
+  m_ui.ionChargeSpinBox->setValue(settings.value("charge", 1).toInt());
+  m_ui.fwhmDoubleSpinBox->setValue(settings.value("fwhm", 0).toDouble());
+  m_ui.binSizeDoubleSpinBox->setValue(settings.value("binSize", 0).toDouble());
+  m_ui.splitter->restoreState(settings.value("splitter").toByteArray());
   settings.endGroup();
 }
 
@@ -116,6 +132,14 @@ PeakShaperDlg::readSettings()
 void
 PeakShaperDlg::setupDialog()
 {
+  // Ranges for various numerical values
+  m_ui.resolutionSpinBox->setRange(0, 1000000);
+  m_ui.fwhmDoubleSpinBox->setRange(0, 10);
+  m_ui.pointCountSpinBox->setRange(5, 500);
+  m_ui.ionChargeSpinBox->setRange(1, 10000);
+
+  // The values above are actually set in readSettings (with default values if
+  // missing in the config settings.)
   readSettings();
 
   // Always start the dialog with the first page of the tab widget,
@@ -129,15 +153,6 @@ PeakShaperDlg::setupDialog()
   // Throughout of *this* dialog window, the normalization factor
   // for the peak shapes (Gaussian, specifically) is going to be 1.
 
-  // Resolution and FWHM stuff
-  m_ui.resolutionSpinBox->setRange(0, 1000000);
-  m_ui.resolutionSpinBox->setValue(0);
-  m_ui.fwhmDoubleSpinBox->setRange(0, 10);
-  m_ui.fwhmDoubleSpinBox->setValue(0);
-
-  m_ui.pointCountSpinBox->setRange(5, 200);
-  m_ui.pointCountSpinBox->setValue(50);
-
   // Get the number of points used to craft the peak curve.
   m_config.setPointCount(m_ui.pointCountSpinBox->value());
 
@@ -167,10 +182,7 @@ PeakShaperDlg::setupDialog()
           this,
           &PeakShaperDlg::lorentzianRadioButtonToggled);
 
-  connect(m_ui.executePushButton,
-          &QPushButton::clicked,
-          this,
-          &PeakShaperDlg::execute);
+  connect(m_ui.runPushButton, &QPushButton::clicked, this, &PeakShaperDlg::run);
 
   connect(m_ui.outputFilePushButton,
           &QPushButton::clicked,
@@ -182,10 +194,9 @@ PeakShaperDlg::setupDialog()
           this,
           &PeakShaperDlg::displayMassSpectrum);
 
-  connect(m_ui.inputDataPointsPlainTextEdit,
-          &QPlainTextEdit::cursorPositionChanged,
-          this,
-          &PeakShaperDlg::inputDataSelectionChanged);
+  connect(
+    m_ui.toFwhmPushButton, &QPushButton::clicked, this, &PeakShaperDlg::toFwhm);
+
 
   connect(m_ui.sortDataPointsPushButton,
           &QPushButton::clicked,
@@ -256,6 +267,18 @@ PeakShaperDlg::fillInThePeakShapers()
           return false;
         }
 
+      // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+      //<< "DataPoint mz value:" << QString("%1").arg(data_point.key(), 0, 'f',
+      // 30);
+
+      // Now that we know that the data point has a correct syntax, we need to
+      // apply to it the charge the user wants it to have.
+      data_point.setKey(data_point.key() / m_config.getCharge());
+
+      // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+      //<< "DataPoint mz value:" << QString("%1").arg(data_point.key(), 0, 'f',
+      // 30);
+
       m_peakShapers.append(new msXpSlibmass::PeakShaper(data_point, m_config));
     }
 
@@ -379,7 +402,8 @@ PeakShaperDlg::sortInputDataPoints()
   QString result;
 
   for(auto &dp : data_points)
-    result += QString("%1 %2\n").arg(dp.key()).arg(dp.val());
+    result +=
+      QString("%1 %2\n").arg(dp.key(), 0, 'f', 30).arg(dp.val(), 0, 'f', 30);
 
   return result;
 }
@@ -401,6 +425,8 @@ PeakShaperDlg::fetchValidateInputData()
 
   if(input_mz_i_pairs.isEmpty())
     {
+      message("The list of centroid peaks is empty");
+
       qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
                << "The list of centroid peaks is empty.";
 
@@ -414,6 +440,8 @@ PeakShaperDlg::fetchValidateInputData()
 
   if(!data_point.isValid())
     {
+      message("No valid DataPoint instance was found");
+
       qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
                << "No valid DataPoint instance was found";
 
@@ -498,6 +526,7 @@ PeakShaperDlg::fetchValidateInputData()
           QString("The bin size is set to: %1.\n").arg(binSize));
     }
 
+  m_config.setCharge(m_ui.ionChargeSpinBox->value());
   m_config.setPointCount(m_ui.pointCountSpinBox->value());
 
 
@@ -609,20 +638,32 @@ PeakShaperDlg::lorentzianRadioButtonToggled(bool checked)
 }
 
 
+
 void
-PeakShaperDlg::message(const QString &message)
+PeakShaperDlg::message(const QString &message, int timeout)
 {
-  m_ui.messageLineEdit->clear();
   m_ui.messageLineEdit->setText(message);
+
+  QTimer::singleShot(timeout, [this]() { m_ui.messageLineEdit->setText(""); });
 }
 
 
 void
-PeakShaperDlg::inputDataSelectionChanged()
+PeakShaperDlg::toFwhm()
 {
-  // We want to fill-in the relevant numerical data using the first element of
-  // the current line, that is the mz of one peak of which the shape has to be
-  // computed.
+  qDebug() << __FILE__ << "@" << __LINE__ << "ENTER" << __FUNCTION__ << "()";
+
+  // The user has selected (or not) a peak centroid m/z value and wants to
+  // compute the corresponding FWHM value based on the resolution.
+
+  int resolution = m_ui.resolutionSpinBox->value();
+  if(!resolution)
+    {
+      message(
+        "Please, set a resolution, select the peak centroid m/z value of "
+        "interest first.");
+      return;
+    }
 
   QTextCursor cursor = m_ui.inputDataPointsPlainTextEdit->textCursor();
 
@@ -635,41 +676,22 @@ PeakShaperDlg::inputDataSelectionChanged()
   double mz = selectedText.toDouble(&ok);
 
   if(!ok)
-    return;
+    {
+      message("The selected text does not convert to a double value.");
+
+      return;
+    }
 
   // Now that we have a mz, we can compute the various values.
 
-  double fwhm    = m_ui.fwhmDoubleSpinBox->value();
-  int resolution = m_ui.resolutionSpinBox->value();
+  double fwhm = mz / resolution;
 
-  if(!fwhm)
-    {
-      // We need to use the resolution.
-      if(!resolution)
-        {
-          message("Please, set either the FWHM or the resolution value");
-          return;
-        }
-
-      // We know resolution is OK, so use it.
-
-      fwhm = mz / resolution;
-
-      m_ui.fwhmDoubleSpinBox->setValue(fwhm);
-    }
-  else
-    {
-      // We need to use fwhm
-
-      resolution = mz / fwhm;
-
-      m_ui.resolutionSpinBox->setValue(resolution);
-    }
+  m_ui.fwhmLabel->setText(QString("%1").arg(fwhm, 0, 'f', 5));
 }
 
 
 void
-PeakShaperDlg::execute()
+PeakShaperDlg::run()
 {
   if(!fetchValidateInputData())
     {
@@ -739,8 +761,7 @@ PeakShaperDlg::execute()
         }
 
       // We want to store a list of all the mz steps for each created spectrum
-      // because we'll need it to know what the size of the final mass
-      // spectrum
+      // because we'll need it to know what the size of the final mass spectrum
       // bins is going to be.
 
       // Make a copy of the peak shaper config, because accessing it modifies
@@ -762,15 +783,15 @@ PeakShaperDlg::execute()
     {
       binSize = fwhm / 10;
 
-      //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-               //<< "The bin size as fwhm/10 is:"
-               //<< QString("%1").arg(binSize, 0, 'f', 6);
+      // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+      //<< "The bin size as fwhm/10 is:"
+      //<< QString("%1").arg(binSize, 0, 'f', 6);
     }
   else
     {
-      //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
-               //<< "The bin size set by the user is:"
-               //<< QString("%1").arg(binSize, 0, 'f', 6);
+      // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+      //<< "The bin size set by the user is:"
+      //<< QString("%1").arg(binSize, 0, 'f', 6);
     }
 
   // Now configure the combination spectrum.
@@ -832,5 +853,10 @@ PeakShaperDlg::displayMassSpectrum()
     m_ui.massSpectrumNameResultsLineEdit->text());
 }
 
-} // namespace msXpSmineXpert
+void
+PeakShaperDlg::setCentroidData(const QString &data)
+{
+  m_ui.inputDataPointsPlainTextEdit->setPlainText(data);
+}
 
+} // namespace msXpSmineXpert
