@@ -409,8 +409,7 @@ ScriptingWnd::setJsReferenceText()
   // We load the history file now. It is part of the source code in the form
   // of libmass/history.html.
 
-  QFile jsReferenceTextFile(":/user-manual/devdoc-javascript-reference.txt");
-
+  QFile jsReferenceTextFile(":/doc/user-manuals/minexpert/xml/devdoc-javascript-reference.txt");
   if(!jsReferenceTextFile.open(QFile::ReadOnly | QFile::Text))
     {
       qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
@@ -1723,7 +1722,6 @@ ScriptingWnd::runScriptFile(const QString &fileName)
         // items.
         logHistory(scriptContents, LogTextColor::Success);
     }
-
 }
 
 
