@@ -270,7 +270,7 @@ MassSpecDataFileLoaderPwiz::containsMobilityData()
   // located.
 
   std::string head;
-	pwiz::msdata::MSData result;
+  pwiz::msdata::MSData result;
 
   if(!canLoadData(m_fileName, this))
     return false;
@@ -290,7 +290,7 @@ MassSpecDataFileLoaderPwiz::containsMobilityData()
                       result,
                       /* int runIndex */ 0);
 
-	pwiz::msdata::SpectrumListPtr spectrumListPtr = result.run.spectrumListPtr;
+  pwiz::msdata::SpectrumListPtr spectrumListPtr = result.run.spectrumListPtr;
 
   if(!spectrumListPtr->size())
     qFatal(
@@ -300,7 +300,7 @@ MassSpecDataFileLoaderPwiz::containsMobilityData()
       __FILE__,
       __LINE__);
 
-	pwiz::msdata::SpectrumPtr spectrumPtr =
+  pwiz::msdata::SpectrumPtr spectrumPtr =
     spectrumListPtr->spectrum(/*index*/ 0, false /*getBinaryData*/);
 
   pwiz::msdata::ScanList scanList = spectrumPtr->scanList;
@@ -557,26 +557,26 @@ MassSpecDataFileLoaderPwiz::nextSpectrum(
               // Retention times are always in minutes.
               m_scanStartTime = cvParam.timeInSeconds() / 60;
 
-							// In some cases, the scan start time value in the mzML file goes
-							// back to smaller values. This happens for IM-MS data from the
-							// Synapt2 instrument from Waters. It almost always goes along a
-							// nan or inf value for the ion mobility drift time value, which
-							// we trap later. So the test below is not useful at the moment.
-							// We keep it for the record.
-							
-              //if(!lter)
-                //m_firstScanStartTime = m_scanStartTime;
+              // In some cases, the scan start time value in the mzML file goes
+              // back to smaller values. This happens for IM-MS data from the
+              // Synapt2 instrument from Waters. It almost always goes along a
+              // nan or inf value for the ion mobility drift time value, which
+              // we trap later. So the test below is not useful at the moment.
+              // We keep it for the record.
 
-              //if(m_scanStartTime < m_firstScanStartTime)
-                //{
+              // if(!lter)
+              // m_firstScanStartTime = m_scanStartTime;
 
-                  //qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-                           //<< "m_scanStartTime:" << m_scanStartTime;
+              // if(m_scanStartTime < m_firstScanStartTime)
+              //{
 
-                  //wasNanOrInf   = true;
+              // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+              //<< "m_scanStartTime:" << m_scanStartTime;
 
-                  //break;
-                //}
+              // wasNanOrInf   = true;
+
+              // break;
+              //}
             }
           else if(cvParam.cvid == pwiz::msdata::MS_ion_mobility_drift_time)
             {
@@ -618,7 +618,8 @@ MassSpecDataFileLoaderPwiz::nextSpectrum(
               iter < scan.scanWindows.at(firstOne).cvParams.size();
               ++iter)
             {
-              pwiz::msdata::CVParam cvParam = scan.scanWindows.at(firstOne).cvParams.at(iter);
+              pwiz::msdata::CVParam cvParam =
+                scan.scanWindows.at(firstOne).cvParams.at(iter);
 
               if(cvParam.cvid == pwiz::msdata::MS_scan_window_lower_limit)
                 {
@@ -674,7 +675,7 @@ MassSpecDataFileLoaderPwiz::createNewSpectrum(
   pwiz::msdata::SpectrumPtr spectrumPtr)
 {
   pwiz::msdata::BinaryDataArrayPtr mzArrayPtr = spectrumPtr->getMZArray();
-  pwiz::msdata::BinaryDataArrayPtr iArrayPtr  = spectrumPtr->getIntensityArray();
+  pwiz::msdata::BinaryDataArrayPtr iArrayPtr = spectrumPtr->getIntensityArray();
 
   // Sanity check:
   if(mzArrayPtr->data.size() != iArrayPtr->data.size())
@@ -1484,7 +1485,8 @@ MassSpecDataFileLoaderPwiz::canLoadData(QString fileName,
 
   // The default reader list handles mzML, mzXML, and other common formats.
   pwiz::msdata::ReaderPtr readerListPtr(new pwiz::msdata::DefaultReaderList);
-  pwiz::msdata::CVID cvId = identifyFileFormat(readerListPtr, fileName.toStdString());
+  pwiz::msdata::CVID cvId =
+    identifyFileFormat(readerListPtr, fileName.toStdString());
 
   // CVTermInfo cvInfo = cvTermInfo(cvId);
   // qDebug() << __FILE__ << __LINE__
@@ -1493,14 +1495,16 @@ MassSpecDataFileLoaderPwiz::canLoadData(QString fileName,
   if(cvId == pwiz::msdata::MS_mzML_format)
     {
       if(pwiz)
-        pwiz->mp_pwizReader = static_cast<pwiz::msdata::ReaderPtr>(new pwiz::msdata::Reader_mzML);
+        pwiz->mp_pwizReader =
+          static_cast<pwiz::msdata::ReaderPtr>(new pwiz::msdata::Reader_mzML);
 
       return MassSpecDataFileFormat::MASS_SPEC_DATA_FILE_FORMAT_MZML;
     }
   else if(cvId == pwiz::msdata::MS_ISB_mzXML_format)
     {
       if(pwiz)
-        pwiz->mp_pwizReader = static_cast<pwiz::msdata::ReaderPtr>(new pwiz::msdata::Reader_mzXML);
+        pwiz->mp_pwizReader =
+          static_cast<pwiz::msdata::ReaderPtr>(new pwiz::msdata::Reader_mzXML);
 
       return MassSpecDataFileFormat::MASS_SPEC_DATA_FILE_FORMAT_MZXML;
     }
@@ -1542,7 +1546,7 @@ MassSpecDataFileLoaderPwiz::readSpectrumCount()
                       /* int runIndex */ 0);
 
   pwiz::msdata::SpectrumListPtr spectrumListPtr = result.run.spectrumListPtr;
-  m_spectrumCount                 = spectrumListPtr->size();
+  m_spectrumCount                               = spectrumListPtr->size();
 
   return m_spectrumCount;
 }
@@ -1895,9 +1899,9 @@ MassSpecDataFileLoaderPwiz::loadDataToDatabase(const QString &dbFileName)
   m_massSpectrum.deleteDataPoints();
   m_massSpectrum.clear();
 
-  m_scanStartTime      = -1;
-  m_curDriftTime       = -1;
-  m_ticIntensity       = 0.0;
+  m_scanStartTime = -1;
+  m_curDriftTime  = -1;
+  m_ticIntensity  = 0.0;
 
   // Counter of the effectively loaded spectra
   m_storedSpectraCount = 0;
@@ -1926,8 +1930,10 @@ MassSpecDataFileLoaderPwiz::loadDataToDatabase(const QString &dbFileName)
       if(spectrumPtr != Q_NULLPTR)
         {
           // For this task we need the Pwiz data
-          pwiz::msdata::BinaryDataArrayPtr mzArrayPtr = spectrumPtr->getMZArray();
-          pwiz::msdata::BinaryDataArrayPtr iArrayPtr  = spectrumPtr->getIntensityArray();
+          pwiz::msdata::BinaryDataArrayPtr mzArrayPtr =
+            spectrumPtr->getMZArray();
+          pwiz::msdata::BinaryDataArrayPtr iArrayPtr =
+            spectrumPtr->getIntensityArray();
 
           // Sanity check:
           if(mzArrayPtr->data.size() != iArrayPtr->data.size())
